package com.loganmagnan.nicknamesplus;

import com.loganmagnan.nicknamesplus.managers.PlayerDataManager;
import com.loganmagnan.nicknamesplus.placeholderapi.PlaceholderAPIProvider;
import com.loganmagnan.nicknamesplus.playerdata.PlayerData;
import com.loganmagnan.nicknamesplus.utils.ClassRegistrationUtils;
import com.loganmagnan.nicknamesplus.utils.ColorUtils;
import com.loganmagnan.nicknamesplus.utils.Utils;
import com.loganmagnan.nicknamesplus.utils.command.CommandFramework;
import com.loganmagnan.nicknamesplus.utils.config.FileConfig;
import com.loganmagnan.nicknamesplus.utils.config.file.Config;
import lombok.Getter;
import lombok.Setter;
import org.bukkit.Bukkit;
import org.bukkit.entity.Player;
import org.bukkit.plugin.java.JavaPlugin;

@Getter
@Setter
public class NicknamesPlus extends JavaPlugin {

    @Getter private static NicknamesPlus instance;

    private FileConfig messagesConfig;

    private PlayerDataManager playerDataManager;

    private CommandFramework commandFramework = new CommandFramework(this);

    public void onEnable() {
        instance = this;

        this.messagesConfig = new FileConfig(this, "messages.yml");

        Bukkit.getConsoleSender().sendMessage(Utils.chatBar);
        Bukkit.getConsoleSender().sendMessage(ColorUtils.getMessageType("&dNicknamesPlus &7- &av" + this.getDescription().getVersion()));
        Bukkit.getConsoleSender().sendMessage(ColorUtils.getMessageType("&7Made by &eLoganM Development"));
        Bukkit.getConsoleSender().sendMessage(Utils.chatBar);

        this.loadCommands();
        this.loadManagers();
        this.loadListeners();
        this.loadRunnables();

        if (this.getServer().getPluginManager().getPlugin("PlaceholderAPI") != null) {
            new PlaceholderAPIProvider(this).register();

            Bukkit.getConsoleSender().sendMessage(ColorUtils.getMessageType("&aPlaceholderAPI registered"));
        }
    }

    public void onDisable() {
        for (Player player : this.getServer().getOnlinePlayers()) {
            PlayerData playerData = this.playerDataManager.getPlayerData(player.getUniqueId());

            this.playerDataManager.savePlayerData(playerData);
        }

        instance = null;
    }

    private void loadCommands() {
        ClassRegistrationUtils.loadCommands("com.loganmagnan.nicknamesplus.commands");
    }

    private void loadManagers() {
        this.playerDataManager = new PlayerDataManager();
    }

    private void loadListeners() {
        ClassRegistrationUtils.loadListeners("com.loganmagnan.nicknamesplus.listeners");
    }

    private void loadRunnables() {

    }
}
